@@ -32,7 +32,7 @@ import time
 import collections
 import binascii
 
-VERSION = (0, 4, 1)
+VERSION = (0, 4, 2)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -715,7 +715,7 @@ class Connection(object):
         elif t == decimal.Decimal:
             return "'" + str(v) + "'"
         elif t == list or t == tuple:
-            return u'{' + u','.join([self.escape_parameter(e) for e in v]) + u'}'
+            return u'ARRAY[' + u','.join([self.escape_parameter(e) for e in v]) + u']'
         else:
             return "'" + str(v) + "'"
 
